Module: EffectiveBootstrapHelper
- Defined in:
- app/helpers/effective_bootstrap_helper.rb
Overview
Boostrap4 Helpers
Constant Summary collapse
- COLLAPSE_SUBSTITUTIONS =
collapse(items.length, class: ‘btn btn-primary’, class: ‘mt-2’) do
items.map { |item| content_tag(:div, item.to_s) }.join.html_safeend
{ 'Show ' => 'Hide ', 'show ' => 'hide ', 'Expand ' => 'Collapse ', 'expand ' => 'collapse ', ' More' => ' Less', ' more' => ' less' }
- DROPDOWN_SPLIT_OPTS =
Button Dropdowns getbootstrap.com/docs/4.0/components/dropdowns/
dropdown do
= dropdown_link_to 'Something', root_path = dropdown_divider = dropdown_link_to 'Another', root_pathButton Dropdowns variations can be :dropup, :dropleft, :dropright split can be true, false right is to right align things
{class: "btn dropdown-toggle dropdown-toggle-split btn-sm btn-outline-primary", type: 'button', 'data-toggle': 'dropdown', 'aria-haspopup': true, 'aria-expanded': false}
- DROPDOWN_UNSPLIT_OPTS =
{class: "btn dropdown-toggle btn-sm btn-outline-primary", type: 'button', 'data-toggle': 'dropdown', 'aria-haspopup': true, 'aria-expanded': false}
- DROPDOWN_DROPLEFT_GROUP_OPTS =
{class: 'btn-group'}
- DROPDOWN_DROPLEFT_OPTS =
{class: 'btn-group dropleft', role: 'group'}
- DROPDOWN_MENU_OPTS =
{class: 'dropdown-menu'}
- DROPDOWN_MENU_RIGHT_OPTS =
{class: 'dropdown-menu dropdown-menu-right'}
- DROPDOWN_BTN_CLASS =
'btn-sm btn-outline-primary'- DROPDOWN_TOGGLE_DROPDOWN =
"<span class='sr-only'>Toggle Dropdown</span>".html_safe
- NUMBERS =
['0', '1', '2', '3', '4', '5', '6', '7', '8', '9']
Instance Method Summary collapse
-
#accordion(options = nil, &block) ⇒ Object
This is a special variant of collapse = accordion do = collapse(‘Add thing…’) do %p Something to add.
- #accordion_collapse(label, opts = {}, &block) ⇒ Object
-
#badge(value = nil, opts = {}) ⇒ Object
(also: #badges)
getbootstrap.com/docs/4.0/components/badge/ = badge(‘Warning’, :secondary) Can pass class or a context.
-
#bootstrap_breadcrumb(root_title: nil, root_path: nil, index_title: nil, index_path: nil, page_title: nil) ⇒ Object
Breadcrumb.
-
#bootstrap_paginate(collection, per_page:, url: nil, window: 2, collection_count: nil, render_single_page: false) ⇒ Object
(also: #paginate)
limit(per_page).offset(offset) }.
- #bootstrap_paginate_tag(index, page, url, params) ⇒ Object
-
#card(value = nil, opts = {}, &block) ⇒ Object
getbootstrap.com/docs/4.0/components/card/ = card(‘title do’) %p Stuff = card(‘Stuff’, header: ‘header title’).
- #collapse(label, opts = {}, &block) ⇒ Object
-
#dots(options = nil, &block) ⇒ Object
This is a special variant of dropdown dots do = dropdown_link_to ‘Edit’, edit_path(thing).
- #dots_link_to(label, path, options = {}) ⇒ Object
- #dropdown(variation: nil, split: true, btn_class: nil, btn_content: nil, right: false, &block) ⇒ Object
-
#dropdown_divider(options = {}) ⇒ Object
Works with dots ao and dropdown do.
-
#dropdown_link_to(label, path, options = {}) ⇒ Object
Works with dots do and dropdown do.
- #effective_bootstrap_human_name(resource, plural: false, prefer_model_name: false) ⇒ Object
- #effective_bootstrap_unique_id ⇒ Object
- #list_group(&block) ⇒ Object
-
#list_group_link_to(label, path, opts = {}) ⇒ Object
List group = list_group_link_to Automatically puts in the ‘active’ class based on request path.
- #merge_class_key(hash, value) ⇒ Object
-
#nav_content_for(name, &block) ⇒ Object
These two are used for advanced menus.
- #nav_divider ⇒ Object
- #nav_dropdown(label, right: false, groups: false, link_class: [], list_class: [], &block) ⇒ Object
- #nav_dropdown_content_for(name, &block) ⇒ Object
- #nav_dropdown_group(label, unique: false, header: true, header_class: nil, &block) ⇒ Object
-
#nav_link_to(resource, path, opts = {}) ⇒ Object
%ul.navbar-nav = nav_link_to ‘Sign In’, new_user_session_path = nav_dropdown ‘Settings’ do = nav_link_to ‘Account Settings’, user_settings_path = nav_divider = nav_link_to ‘Sign In’, new_user_session_path, method: :delete.
- #reveal_mail_to(email) ⇒ Object
- #tab(label, options = {}, &block) ⇒ Object
-
#tabs(active: nil, unique: false, ignore_save_tab: false, list: {}, content: {}, &block) ⇒ Object
If you pass active ‘label’ it will make that tab active.
- #vertical_tabs(active: nil, unique: false, list: {}, content: {}, &block) ⇒ Object
Instance Method Details
#accordion(options = nil, &block) ⇒ Object
This is a special variant of collapse
accordion do
= collapse('Add thing...') do
p Something to add
10 11 12 13 14 15 16 17 18 19 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 10 def accordion( = nil, &block) ( ||= {})[:class] = "accordion #{options.delete(:class)}".strip id = "accordion-#{effective_bootstrap_unique_id}" @_accordion_active = id content = content_tag(:div, capture(&block), .merge(id: id)) @_accordion_active = nil content end |
#accordion_collapse(label, opts = {}, &block) ⇒ Object
21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 21 def accordion_collapse(label, opts = {}, &block) raise 'expected a block' unless block_given? id = "collapse-#{effective_bootstrap_unique_id}" show = (opts.delete(:show) == true) link_opts = { 'data-toggle': 'collapse', role: 'button', href: "##{id}", 'aria-controls': "##{id}", 'aria-expanded': show } link_opts[:class] = opts.delete(:link_class) || 'btn btn-link' div_class = opts.delete(:div_class) card_class = opts.delete(:card_class) || 'card card-body my-2' # Accordion collapse content_tag(:div, class: "card mb-0") do content_tag(:div, class: "card-header") do content_tag(:h2, class: "mb-0") do content_tag(:button, label, link_opts.merge(class: "btn btn-link")) end end + content_tag(:div, id: id, class: ['collapse', div_class, ('show' if show)].compact.join(' '), "data-parent": "##{@_accordion_active}") do content_tag(:div, capture(&block), class: "card-body") end end end |
#badge(value = nil, opts = {}) ⇒ Object Also known as: badges
getbootstrap.com/docs/4.0/components/badge/
badge(‘Warning’, :secondary)
Can pass class or a context
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 49 def badge(value = nil, opts = {}) value = Array(value) - [nil, ''] return if value.blank? badge_opts = opts badge_opts = {context: opts} unless badge_opts.kind_of?(Hash) context = badge_opts[:context].to_s.sub('badge-', '').presence || 'secondary' badge_opts[:class] ||= "badge badge-#{context}" value.map { |value| content_tag(:span, value, badge_opts) }.join(' ').html_safe end |
#bootstrap_breadcrumb(root_title: nil, root_path: nil, index_title: nil, index_path: nil, page_title: nil) ⇒ Object
Breadcrumb
getbootstrap.com/docs/4.0/components/breadcrumb/ Builds a breadcrumb based on the controller namespace, action and @page_title instance variable
406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 406 def (root_title: nil, root_path: nil, index_title: nil, index_path: nil, page_title: nil) effective_resource = (@_effective_resource || Effective::Resource.new(controller_path)) resource = instance_variable_get('@' + effective_resource.name) if effective_resource.name root_title ||= 'Home' root_path ||= '/' index_title ||= controller.class.name.split('::').last.sub('Controller', '').titleize index_path ||= effective_resource.action_path(:index) || request.path.split('/')[0...-1].join('/') page_title ||= (@page_title || resource&.to_s || controller.action_name.titleize) # Build items # An array of arrays [[title, url]] items = [] # Namespaces Array(effective_resource.namespace).each do |namespace| items << [namespace.titleize, '/' + namespace] end # Home items << [root_title, '/'] unless items.present? # Controller index action items << [index_title, index_path] unless controller.action_name == 'index' # Always items << [page_title, nil] # Now take items and turn them into breadcrumbs content_tag(:ol, class: 'breadcrumb') do (items[0...-1].map do |title, path| content_tag(:li, link_to(title, path, title: title), class: 'breadcrumb-item') end + items[-1..-1].map do |title, path| content_tag(:li, title, class: 'breadcrumb-item active', 'aria-current': 'page') end).join.html_safe end end |
#bootstrap_paginate(collection, per_page:, url: nil, window: 2, collection_count: nil, render_single_page: false) ⇒ Object Also known as: paginate
limit(per_page).offset(offset) }
Add this to your controller: Add this to your view %nav= paginate(@posts, per_page: 10)
468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 468 def bootstrap_paginate(collection, per_page:, url: nil, window: 2, collection_count: nil, render_single_page: false) raise 'expected an ActiveRecord::Relation' unless collection.respond_to?(:limit) && collection.respond_to?(:offset) collection_count ||= collection.limit(nil).offset(nil).count # You can pass the total count, or not. page = (params[:page] || 1).to_i last = (collection_count.to_f / per_page).ceil return unless (last > 1 || render_single_page) # If there's only 1 page, don't render a pagination at all. # Build URL uri = URI(url || request.fullpath) params = Rack::Utils.parse_nested_query(uri.query) url = uri.path + '?' # Pagination Tags prev_tag = content_tag(:li, class: ['page-item', ('disabled' if page <= 1)].compact.join(' ')) do link_to(content_tag(:span, 'Previous'.html_safe), (page <= 1 ? '#' : url + params.merge('page' => page - 1).to_query), class: 'page-link', 'aria-label': 'Previous', title: 'Previous', 'aria-disabled': ('true' if page <= 1), 'tabindex': ('-1' if page <= 1) ) end next_tag = content_tag(:li, class: ['page-item', ('disabled' if page >= last)].compact.join(' ')) do link_to(content_tag(:span, 'Next'.html_safe), (page >= last ? '#' : url + params.merge('page' => page + 1).to_query), class: 'page-link', 'aria-label': 'Next', title: 'Next', 'aria-disabled': ('true' if page >= last), 'tabindex': ('-1' if page >= last) ) end dots_tag = content_tag(:li, class: 'page-item disabled') do link_to('...', '#', class: 'page-link', 'aria-label': '...', 'aria-disabled': true, tabindex: '-1') end # Calculate Windows length = 1 + (window * 2) left = 1.upto(last).to_a.first(length) right = 1.upto(last).to_a.last(length) center = [] max = length + 2 if last <= max left = left - right right = right - left elsif left.include?(page + 1) right = [last] left = left - right elsif right.include?(page - 1) left = [1] right = right - left else left = [1] right = [last] center = (page - window + 1).upto(page + window - 1).to_a end # Render the pagination content_tag(:ul, class: 'pagination') do [ prev_tag, left.map { |index| bootstrap_paginate_tag(index, page, url, params) }, (dots_tag if last > max && left == [1]), center.map { |index| bootstrap_paginate_tag(index, page, url, params) }, (dots_tag if last > max && right == [last]), right.map { |index| bootstrap_paginate_tag(index, page, url, params) }, next_tag ].flatten.join.html_safe end end |
#bootstrap_paginate_tag(index, page, url, params) ⇒ Object
536 537 538 539 540 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 536 def bootstrap_paginate_tag(index, page, url, params) content_tag(:li, class: ['page-item', ('active' if index == page)].compact.join(' '), title: "Page #{index}") do link_to(index, (url + params.merge('page' => index).to_query), class: 'page-link') end end |
#card(value = nil, opts = {}, &block) ⇒ Object
getbootstrap.com/docs/4.0/components/card/
card(‘title do’)
p Stuff
card(‘Stuff’, header: ‘header title’)
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 67 def card(value = nil, opts = {}, &block) raise('expected a block') unless block_given? if value.kind_of?(Hash) opts = value; value = nil end header = opts.delete(:header) title = opts.delete(:title) || effective_bootstrap_human_name(value) content_tag(:div, merge_class_key(opts, 'card mb-4')) do header = content_tag(:div, header, class: 'card-header') if header.present? body = content_tag(:div, class: 'card-body') do if title.present? content_tag(:h5, title, class: 'card-title') + capture(&block) else capture(&block) end end header ? (header + body) : body end end |
#collapse(label, opts = {}, &block) ⇒ Object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 122 def collapse(label, opts = {}, &block) raise 'expected a block' unless block_given? return accordion_collapse(label, opts, &block) if @_accordion_active id = "collapse-#{effective_bootstrap_unique_id}" show = (opts.delete(:show) == true) # Figure out all the button / link options link_opts = { 'data-toggle': 'collapse', role: 'button', href: "##{id}", 'aria-controls': "##{id}", 'aria-expanded': show } # Two link labels = opts.delete(:expand) || label.to_s.tap do |label| COLLAPSE_SUBSTITUTIONS.each { |show, hide| label.sub!(hide, show) } end + icon('chevron-down') label_collapse = opts.delete(:collapse) || label.to_s.tap do |label| COLLAPSE_SUBSTITUTIONS.each { |show, hide| label.sub!(show, hide) } end + icon('chevron-up') # The link html classes link_opts[:class] = opts.delete(:link_class) || 'btn btn-link' link_opts[:class] += ' effective-collapse-actions hidden-print' link_opts[:class] += ' collapsed' unless show # The div and the card now div_class = opts.delete(:div_class) card_class = opts.delete(:card_class) || 'card card-body my-2' # Normal collapse link_tag = content_tag(:a, link_opts) do content_tag(:div, .html_safe, class: 'collapse-label-expand') + content_tag(:div, label_collapse.html_safe, class: 'collapse-label-collapse') end div_tag = content_tag(:div, id: id, class: ['effective-collapse collapse', div_class, ('show' if show)].compact.join(' ')) do content_tag(:div, capture(&block), class: card_class) end link_tag + div_tag end |
#dots(options = nil, &block) ⇒ Object
This is a special variant of dropdown dots do
= dropdown_link_to 'Edit', edit_path(thing)
240 241 242 243 244 245 246 247 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 240 def dots( = nil, &block) ( ||= {})[:class] = "dropdown dropdown-dots #{options.delete(:class)}".strip content_tag(:div, ) do content_tag(:button, class: "btn btn-dots dropdown-toggle #{options.delete(:button_class)}", 'aria-expanded': true, 'aria-haspopup': true, 'data-toggle': 'dropdown', type: 'button') do end + content_tag(:div, capture(&block), class: 'dropdown-menu') end end |
#dots_link_to(label, path, options = {}) ⇒ Object
249 250 251 252 253 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 249 def dots_link_to(label, path, = {}) [:class] = [[:class], 'dropdown-item'].compact.join(' ') concat link_to(label, path, ) end |
#dropdown(variation: nil, split: true, btn_class: nil, btn_content: nil, right: false, &block) ⇒ Object
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 188 def dropdown(variation: nil, split: true, btn_class: nil, btn_content: nil, right: false, &block) raise 'expected a block' unless block_given? btn_class ||= DROPDOWN_BTN_CLASS # Process all dropdown_link_tos @_dropdown_link_tos = [] @_dropdown_split = split = btn_class yield return @_dropdown_link_tos.first if @_dropdown_link_tos.length <= 1 # Build tags first = @_dropdown_link_tos.first = (split ? DROPDOWN_SPLIT_OPTS : DROPDOWN_UNSPLIT_OPTS) if btn_class != DROPDOWN_BTN_CLASS [:class] = [:class].sub(DROPDOWN_BTN_CLASS, btn_class) end = content_tag(:button, ) do btn_content || DROPDOWN_TOGGLE_DROPDOWN end = (right ? DROPDOWN_MENU_RIGHT_OPTS : DROPDOWN_MENU_OPTS) = if split content_tag(:div, @_dropdown_link_tos[1..-1].join.html_safe, ) else content_tag(:div, @_dropdown_link_tos.join.html_safe, ) end @_dropdown_link_tos = nil if split && variation == :dropleft content_tag(:div, DROPDOWN_DROPLEFT_GROUP_OPTS) do content_tag(:div, ( + ), DROPDOWN_DROPLEFT_OPTS) + first.html_safe end elsif split content_tag(:div, class: 'btn-group') do content_tag(:div, (first + + ), class: "btn-group #{variation}", role: 'group') end else content_tag(:div, ( + ), class: 'dropdown') end end |
#dropdown_divider(options = {}) ⇒ Object
Works with dots ao and dropdown do
276 277 278 279 280 281 282 283 284 285 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 276 def dropdown_divider( = {}) [:class] = [[:class], 'dropdown-divider'].compact.join(' ') unless @_dropdown_link_tos content_tag(:div, '', ) else @_dropdown_link_tos << content_tag(:div, '', ) nil end end |
#dropdown_link_to(label, path, options = {}) ⇒ Object
Works with dots do and dropdown do
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 256 def dropdown_link_to(label, path, = {}) btn_class = .delete(:btn_class).presence || || 'btn-outline-primary' unless @_dropdown_link_tos [:class] = ([:class] ? "dropdown-item #{options[:class]}" : 'dropdown-item') return link_to(label, path, ) end if @_dropdown_link_tos.length == 0 && @_dropdown_split [:class] = ([:class] ? "btn #{btn_class} #{options[:class]}" : "btn #{btn_class}") else [:class] = ([:class] ? "dropdown-item #{options[:class]}" : 'dropdown-item') end @_dropdown_link_tos << link_to(label, path, ) nil end |
#effective_bootstrap_human_name(resource, plural: false, prefer_model_name: false) ⇒ Object
660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 660 def effective_bootstrap_human_name(resource, plural: false, prefer_model_name: false) if resource.kind_of?(String) resource elsif resource.respond_to?(:datatable_name) et(resource) elsif resource.respond_to?(:model_name) == false resource.to_s elsif resource.kind_of?(ActiveRecord::Relation) || plural ets(resource) elsif resource.kind_of?(Class) || prefer_model_name et(resource) else resource.to_s end end |
#effective_bootstrap_unique_id ⇒ Object
676 677 678 679 680 681 682 683 684 685 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 676 def effective_bootstrap_unique_id # Set the first unique value @_effective_bootstrap_unique_id ||= Time.zone.now.to_i # Everytime we access this function make a new one @_effective_bootstrap_unique_id = @_effective_bootstrap_unique_id + 1 # Return the updated value @_effective_bootstrap_unique_id end |
#list_group(&block) ⇒ Object
287 288 289 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 287 def list_group(&block) content_tag(:div, yield, class: 'list-group') end |
#list_group_link_to(label, path, opts = {}) ⇒ Object
List group
list_group_link_to
Automatically puts in the ‘active’ class based on request path
294 295 296 297 298 299 300 301 302 303 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 294 def list_group_link_to(label, path, opts = {}) # Regular link item opts[:class] = if request.fullpath.include?(path) [opts[:class], 'list-group-item list-group-item-action active'].compact.join(' ') else [opts[:class], 'list-group-item list-group-item-action'].compact.join(' ') end link_to(label.to_s, path, opts) end |
#merge_class_key(hash, value) ⇒ Object
650 651 652 653 654 655 656 657 658 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 650 def merge_class_key(hash, value) return { :class => value } unless hash.kind_of?(Hash) if hash[:class].present? hash.merge!(:class => "#{hash[:class]} #{value}") else hash.merge!(:class => value) end end |
#nav_content_for(name, &block) ⇒ Object
These two are used for advanced menus. When using content_for to capture inside nav dropdowns
383 384 385 386 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 383 def nav_content_for(name, &block) raise('expected a block') unless block_given? content_for(name) { yield } end |
#nav_divider ⇒ Object
378 379 380 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 378 def nav_divider content_tag(:div, '', class: 'dropdown-divider') end |
#nav_dropdown(label, right: false, groups: false, link_class: [], list_class: [], &block) ⇒ Object
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 335 def nav_dropdown(label, right: false, groups: false, link_class: [], list_class: [], &block) raise 'expected a block' unless block_given? id = "dropdown-#{effective_bootstrap_unique_id}" div_class = ['dropdown-menu', *('dropdown-menu-right' if right), *('dropdown-groups' if groups)].join(' ') # Render content @_nav_mode = :dropdown content = capture(&block) @_nav_mode = nil return ''.html_safe if content.blank? content_tag(:li, class: 'nav-item dropdown') do content_tag(:a, class: 'nav-link dropdown-toggle', href: '#', id: id, role: 'button', 'data-toggle': 'dropdown', 'aria-haspopup': true, 'aria-expanded': false) do label.html_safe end + content_tag(:div, class: div_class, 'aria-labelledby': id) do content end end end |
#nav_dropdown_content_for(name, &block) ⇒ Object
388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 388 def nav_dropdown_content_for(name, &block) raise('expected a block') unless block_given? original = @_nav_mode begin @_nav_mode = :dropdown content_for(name) { yield } ensure @_nav_mode = original end end |
#nav_dropdown_group(label, unique: false, header: true, header_class: nil, &block) ⇒ Object
357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 357 def nav_dropdown_group(label, unique: false, header: true, header_class: nil, &block) raise 'expected a block' unless block_given? div_class = [ 'dropdown-group', ("dropdown-group-#{effective_bootstrap_unique_id}" if unique), ("dropdown-group-first" if label.blank?), ("dropdown-group-#{label.to_s.parameterize}" if label.present?) ].compact.join(' ') header_class ||= 'dropdown-header' content_tag(:div, class: div_class) do if label.present? && header content_tag(:h6, label, class: header_class) + capture(&block) else capture(&block) end end end |
#nav_link_to(resource, path, opts = {}) ⇒ Object
%ul.navbar-nav
= nav_link_to 'Sign In', new_user_session_path
= nav_dropdown 'Settings' do
= nav_link_to 'Account Settings', user_settings_path
= nav_divider
= nav_link_to 'Sign In', new_user_session_path, method: :delete
If you pass a class, it will authorize and display that class if you have :index access
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 316 def nav_link_to(resource, path, opts = {}) return if resource.kind_of?(Class) && !EffectiveResources.(self, :index, resource) label = opts.delete(:label) || effective_bootstrap_human_name(resource, plural: true, prefer_model_name: true) if @_nav_mode == :dropdown # We insert dropdown-items return link_to(label, path, merge_class_key(opts, 'dropdown-item')) end strict = opts.delete(:strict) active = (strict ? (request.fullpath == path) : request.fullpath.include?(path)) # Regular nav link item content_tag(:li, class: (active ? 'nav-item active' : 'nav-item')) do link_to(label, path, merge_class_key(opts, 'nav-link')) end end |
#reveal_mail_to(email) ⇒ Object
545 546 547 548 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 545 def reveal_mail_to(email) raise('expected an email') unless email.kind_of?(String) && email.include?('@') link_to 'Click to reveal email', '#', 'data-mailto-rot13' => email.tr('A-Za-z', 'N-ZA-Mn-za-m') end |
#tab(label, options = {}, &block) ⇒ Object
599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 599 def tab(label, = {}, &block) label = effective_bootstrap_human_name(label, prefer_model_name: true) (@_tab_labels.push(label) and return) if @_tab_mode == :validate controls = .delete(:controls) || label.to_s.parameterize.gsub('_', '-') controls = "item-#{controls}" if NUMBERS.include?(controls[0]) # Can't start with a number controls = controls[1..-1] if controls[0] == '#' controls = "#{controls}-#{@_tab_unique}" if @_tab_unique active = (@_tab_active == :first || @_tab_active == label) @_tab_active = nil if @_tab_active == :first if @_tab_mode == :tablist_vertical content_tag(:a, label, id: ('tab-' + controls), class: ['nav-link', ('active' if active)].compact.join(' '), href: '#' + controls, 'aria-controls': controls, 'aria-selected': active.to_s, 'data-toggle': 'tab', role: 'tab') elsif @_tab_mode == :tablist # Inserting the label into the tablist top content_tag(:li, class: 'nav-item') do content_tag(:a, label, id: ('tab-' + controls), class: ['nav-link', ('active' if active)].compact.join(' '), href: '#' + controls, 'aria-controls': controls, 'aria-selected': active.to_s, 'data-toggle': 'tab', role: 'tab') end else # Inserting the content into the tab itself classes = ['tab-pane', 'fade', ('show active' if active), [:class].presence].compact.join(' ') content_tag(:div, id: controls, class: classes, role: 'tabpanel', 'aria-labelledby': ('tab-' + controls), 'data-tab-label': label) do yield end end end |
#tabs(active: nil, unique: false, ignore_save_tab: false, list: {}, content: {}, &block) ⇒ Object
If you pass active ‘label’ it will make that tab active. Otherwise first. Unique will make sure the tab html IDs are unique $(‘#tab-demographics’).tab(‘show’)
563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 563 def tabs(active: nil, unique: false, ignore_save_tab: false, list: {}, content: {}, &block) raise 'expected a block' unless block_given? # The Active Tab might be set from a previous form submission, or passed into helper tab_active = session[:_tabs].try(:pop) unless ignore_save_tab tab_active ||= active # If an active tab is passed, we validate we have a tab with that label, or fallback to first if tab_active.present? @_tab_mode = :validate @_tab_labels = [] yield tab_active = nil unless @_tab_labels.include?(tab_active) end tab_active ||= :first if tab_active.nil? @_tab_unique = effective_bootstrap_unique_id if unique # Generate the html in two passes content_tag(:ul, {class: 'nav nav-tabs', role: 'tablist'}.merge(list)) do @_tab_mode = :tablist @_tab_active = tab_active yield # Yield to tab the first time end + content_tag(:div, {class: 'tab-content'}.merge(content)) do @_tab_mode = :content @_tab_active = tab_active yield # Yield to tab the second time end end |
#vertical_tabs(active: nil, unique: false, list: {}, content: {}, &block) ⇒ Object
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 |
# File 'app/helpers/effective_bootstrap_helper.rb', line 627 def vertical_tabs(active: nil, unique: false, list: {}, content: {}, &block) raise 'expected a block' unless block_given? @_tab_mode = :tablist_vertical @_tab_active = (active || :first) @_tab_unique = effective_bootstrap_unique_id if unique content_tag(:div, class: 'row border') do content_tag(:div, class: 'col-3 border-right') do content_tag(:div, {class: 'nav flex-column nav-pills my-2', role: 'tablist', 'aria-orientation': :vertical}.merge(list)) do yield # Yield to tab the first time end end + content_tag(:div, class: 'col-9') do content_tag(:div, {class: 'tab-content my-2'}.merge(content)) do @_tab_mode = :content @_tab_active = (active || :first) yield # Yield to tab the second time end end end end |