Module: EffectiveBootstrapHelper

Defined in:
app/helpers/effective_bootstrap_helper.rb

Overview

Boostrap4 Helpers

Instance Method Summary collapse

Instance Method Details

#bootstrap_paginate(collection, per_page:, url: nil, window: 2, collection_count: nil, render_single_page: false) ⇒ Object Also known as: paginate

limit(per_page).offset(offset) }

Add this to your controller: Add this to your view %nav= paginate(@posts, per_page: 10)



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'app/helpers/effective_bootstrap_helper.rb', line 201

def bootstrap_paginate(collection, per_page:, url: nil, window: 2, collection_count: nil, render_single_page: false)
  raise 'expected an ActiveRecord::Relation' unless collection.respond_to?(:limit) && collection.respond_to?(:offset)

  collection_count ||= collection.limit(nil).offset(nil).count # You can pass the total count, or not.

  page = (params[:page] || 1).to_i
  last = (collection_count.to_f / per_page).ceil

  return unless (last > 1 || render_single_page) # If there's only 1 page, don't render a pagination at all.

  # Build URL
  uri = URI(url || request.fullpath)
  params = Rack::Utils.parse_nested_query(uri.query)
  url = uri.path + '?'

  # Pagination Tags
  prev_tag = (:li, class: ['page-item', ('disabled' if page <= 1)].compact.join(' ')) do
    link_to((:span, 'Previous'.html_safe), (page <= 1 ? '#' : url + params.merge('page' => page - 1).to_query),
      class: 'page-link', 'aria-label': 'Previous', title: 'Previous', 'aria-disabled': ('true' if page <= 1), 'tabindex': ('-1' if page <= 1)
    )
  end

  next_tag = (:li, class: ['page-item', ('disabled' if page >= last)].compact.join(' ')) do
    link_to((:span, 'Next'.html_safe), (page >= last ? '#' : url + params.merge('page' => page + 1).to_query),
      class: 'page-link', 'aria-label': 'Next', title: 'Next', 'aria-disabled': ('true' if page >= last), 'tabindex': ('-1' if page >= last)
    )
  end

  dots_tag = (:li, class: 'page-item disabled') do
    link_to('...', '#', class: 'page-link', 'aria-label': '...', 'aria-disabled': true, tabindex: '-1')
  end

  # Calculate Windows
  length = 1 + (window * 2)
  left = 1.upto(last).to_a.first(length)
  right = 1.upto(last).to_a.last(length)
  center = []

  if last <= (length + 2)
    left = left - right
    right = right - left
  elsif left.include?(page + 1)
    right = [last]
    left = left - right
  elsif right.include?(page - 1)
    left = [1]
    right = right - left
  else
    left = [1]
    right = [last]
    center = (page - window + 1).upto(page + window - 1).to_a
  end

  # Render the pagination
  (:ul, class: 'pagination') do
    [
      prev_tag,
      left.map { |index| bootstrap_paginate_tag(index, page, url, params) },
      (dots_tag if last > length && left == [1]),
      center.map { |index| bootstrap_paginate_tag(index, page, url, params) },
      (dots_tag if last > length && right == [last]),
      right.map { |index| bootstrap_paginate_tag(index, page, url, params) },
      next_tag
    ].flatten.join.html_safe
  end
end

#bootstrap_paginate_tag(index, page, url, params) ⇒ Object



268
269
270
271
272
# File 'app/helpers/effective_bootstrap_helper.rb', line 268

def bootstrap_paginate_tag(index, page, url, params)
  (:li, class: ['page-item', ('active' if index == page)].compact.join(' '), title: "Page #{index}") do
    link_to(index, (url + params.merge('page' => index).to_query), class: 'page-link')
  end
end

#collapse(label, opts = {}, &block) ⇒ Object

collapse(items.length, class: 'btn btn-primary', class: 'mt-2') do items.map { |item| content_tag(:div, item.to_s) }.join.html_safe end



15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
# File 'app/helpers/effective_bootstrap_helper.rb', line 15

def collapse(label, opts = {}, &block)
  raise 'expected a block' unless block_given?

  id = "collapse-#{''.object_id}"
  show = (opts.delete(:show) == true)

  link_opts = { 'data-toggle': 'collapse', role: 'button', href: "##{id}", 'aria-controls': "##{id}", 'aria-expanded': show }
  div_class = opts.delete(:div_class)
  card_class = opts.delete(:card_class) || 'my-2'

  (:a, label, link_opts.merge(opts)) +
  (:div, id: id, class: ['collapse', div_class, ('show' if show)].compact.join(' ')) do
    (:div, capture(&block), class: ['card', 'card-body', card_class].compact.join(' '))
  end
end

#dots(options = nil, &block) ⇒ Object

This is a special variant of dropdown dots do

dropdown_link_to 'Edit', edit_path(thing)



76
77
78
79
80
81
82
83
# File 'app/helpers/effective_bootstrap_helper.rb', line 76

def dots(options = nil, &block)
  (options ||= {})[:class] = "dropdown dropdown-dots #{options.delete(:class)}".strip

  (:span, options) do
    (:button, class: "btn btn-dots dropdown-toggle #{options.delete(:button_class)}", 'aria-expanded': true, 'aria-haspopup': true, 'data-toggle': 'dropdown', type: 'button') do
    end + (:div, capture(&block), class: 'dropdown-menu')
  end
end


85
86
87
88
89
# File 'app/helpers/effective_bootstrap_helper.rb', line 85

def dots_link_to(label, path, options = {})
  options[:class] = [options[:class], 'dropdown-item'].compact.join(' ')

  concat link_to(label, path, options)
end

Button Dropdowns https://getbootstrap.com/docs/4.0/components/dropdowns/

dropdown do

dropdown_link_to 'Something', root_path

dropdown_divider

dropdown_link_to 'Another', root_path

Button Dropdowns variations can be :dropup, :dropleft, :dropright split can be true, false right is to right align things



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'app/helpers/effective_bootstrap_helper.rb', line 43

def dropdown(variation: nil, split: true, btn_class: nil, right: false, &block)
  raise 'expected a block' unless block_given?

  btn_class = btn_class.presence || 'btn-outline-primary'

  @_dropdown_link_tos = []; yield

  return @_dropdown_link_tos.first if @_dropdown_link_tos.length <= 1

  retval = if split
    first = @_dropdown_link_tos.first
    menu = (:div, @_dropdown_link_tos[1..-1].join.html_safe, class: ['dropdown-menu', ('dropdown-menu-right' if right)].compact.join(' '))
    split = (:button, class: "btn #{btn_class} dropdown-toggle dropdown-toggle-split", type: 'button', 'data-toggle': 'dropdown', 'aria-haspopup': true, 'aria-expanded': false) do
      (:span, 'Toggle Dropdown', class: 'sr-only')
    end

    (:div, class: 'btn-group') do
      (:div, class: ['btn-group', variation.to_s.presence].compact.join(' '), role: 'group') do
        [:dropleft].include?(variation) ? (split + menu) : (first + split + menu)
      end + ([:dropleft].include?(variation) ? first : '').html_safe
    end
  else
    raise 'split false is unsupported'
  end

  @_dropdown_link_tos = nil

  retval
end

Works with dots ao and dropdown do



112
113
114
115
116
117
118
119
# File 'app/helpers/effective_bootstrap_helper.rb', line 112

def dropdown_divider
  unless @_dropdown_link_tos
    (:div, '', class: 'dropdown-divider')
  else
    @_dropdown_link_tos << (:div, '', class: 'dropdown-divider')
    nil
  end
end

Works with dots do and dropdown do



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'app/helpers/effective_bootstrap_helper.rb', line 92

def dropdown_link_to(label, path, options = {})
  btn_class = options.delete(:btn_class).presence || 'btn-outline-primary'

  unless @_dropdown_link_tos
    options[:class] = [options[:class], 'dropdown-item'].compact.join(' ')
    return link_to(label, path, options)
  end

  if @_dropdown_link_tos.length == 0
    options[:class] = [options[:class], 'btn', btn_class].compact.join(' ')
  else
    options[:class] = [options[:class], 'dropdown-item'].compact.join(' ')
  end

  @_dropdown_link_tos << link_to(label, path, options)

  nil
end

#list_group(&block) ⇒ Object



121
122
123
# File 'app/helpers/effective_bootstrap_helper.rb', line 121

def list_group(&block)
  (:div, yield, class: 'list-group')
end

List group

list_group_link_to

Automatically puts in the 'active' class based on request path



128
129
130
131
132
133
134
135
136
137
# File 'app/helpers/effective_bootstrap_helper.rb', line 128

def list_group_link_to(label, path, opts = {})
  # Regular link item
  opts[:class] = if request.fullpath.include?(path)
    [opts[:class], 'list-group-item active'].compact.join(' ')
  else
    [opts[:class], 'list-group-item'].compact.join(' ')
  end

  link_to(label.to_s, path, opts)
end

#merge_class_key(hash, value) ⇒ Object



328
329
330
331
332
333
334
335
336
# File 'app/helpers/effective_bootstrap_helper.rb', line 328

def merge_class_key(hash, value)
  return { :class => value } unless hash.kind_of?(Hash)

  if hash[:class].present?
    hash.merge!(:class => "#{hash[:class]} #{value}")
  else
    hash.merge!(:class => value)
  end
end


176
177
178
# File 'app/helpers/effective_bootstrap_helper.rb', line 176

def nav_divider
  (:div, '', class: 'dropdown-divider')
end


162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'app/helpers/effective_bootstrap_helper.rb', line 162

def nav_dropdown(label, right: false, link_class: [], list_class: [], &block)
  raise 'expected a block' unless block_given?

  id = "dropdown-#{''.object_id}"

  (:li, class: 'nav-item dropdown') do
    (:a, class: 'nav-link dropdown-toggle', href: '#', id: id, role: 'button', 'data-toggle': 'dropdown', 'aria-haspopup': true, 'aria-expanded': false) do
      label.html_safe
    end + (:div, class: (right ? 'dropdown-menu dropdown-menu-right' : 'dropdown-menu'), 'aria-labelledby': id) do
      @_nav_mode = :dropdown; yield; @_nav_mode = nil
    end
  end
end

%ul.navbar-nav

nav_link_to 'Sign In', new_user_session_path

nav_dropdown 'Settings' do

= nav_link_to 'Account Settings', user_settings_path
= nav_divider
= nav_link_to 'Sign In', new_user_session_path, method: :delete


148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'app/helpers/effective_bootstrap_helper.rb', line 148

def nav_link_to(label, path, opts = {})
  if @_nav_mode == :dropdown  # We insert dropdown-items
    return link_to(label, path, merge_class_key(opts, 'dropdown-item'))
  end

  strict = opts.delete(:strict)
  active = (strict ? (request.fullpath == path) : request.fullpath.include?(path))

  # Regular nav link item
  (:li, class: (active ? 'nav-item active' : 'nav-item')) do
    link_to(label, path, merge_class_key(opts, 'nav-link'))
  end
end

#tab(label, options = {}, &block) ⇒ Object



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'app/helpers/effective_bootstrap_helper.rb', line 307

def tab(label, options = {}, &block)
  controls = options.delete(:controls) || label.to_s.parameterize.gsub('_', '-')
  controls = controls[1..-1] if controls[0] == '#'
  controls = "#{controls}-#{@_tab_unique}" if @_tab_unique

  active = (@_tab_active == :first || @_tab_active == label)

  @_tab_active = nil if @_tab_active == :first

  if @_tab_mode == :tablist # Inserting the label into the tablist top
    (:li, class: 'nav-item') do
      (:a, label, id: ('tab-' + controls), class: ['nav-link', ('active' if active)].compact.join(' '), href: '#' + controls, 'aria-controls': controls, 'aria-selected': active.to_s, 'data-toggle': 'tab', role: 'tab')
    end
  else # Inserting the content into the tab itself
    classes = ['tab-pane', 'fade', ('show active' if active), options[:class].presence].compact.join(' ')
    (:div, id: controls, class: classes, role: 'tabpanel', 'aria-labelledby': ('tab-' + controls)) do
      yield
    end
  end
end

#tabs(active: nil, unique: false, list: {}, content: {}, &block) ⇒ Object

If you pass active 'label' it will make that tab active. Otherwise first. Unique will make sure the tab html IDs are unique $('#tab-demographics').tab('show')



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'app/helpers/effective_bootstrap_helper.rb', line 290

def tabs(active: nil, unique: false, list: {}, content: {}, &block)
  raise 'expected a block' unless block_given?

  @_tab_mode = :tablist
  @_tab_active = (active || :first)
  @_tab_unique = ''.object_id if unique

  (:ul, {class: 'nav nav-tabs', role: 'tablist'}.merge(list)) do
    yield # Yield to tab the first time
  end +
  (:div, {class: 'tab-content'}.merge(content)) do
    @_tab_mode = :content
    @_tab_active = (active || :first)
    yield # Yield to tab the second time
  end
end