Module: EffectiveBootstrapHelper

Defined in:
app/helpers/effective_bootstrap_helper.rb

Overview

Boostrap4 Helpers

Instance Method Summary collapse

Instance Method Details

#dots(options = nil, &block) ⇒ Object

This is a special variant of dropdown dots do

dropdown_link_to 'Edit', edit_path(thing)



47
48
49
50
51
52
53
54
# File 'app/helpers/effective_bootstrap_helper.rb', line 47

def dots(options = nil, &block)
  (options ||= {})[:class] = "dropdown dropdown-dots #{options.delete(:class)}".strip

  (:span, options) do
    (:button, class: "btn btn-dots dropdown-toggle #{options.delete(:button_class)}", 'aria-expanded': true, 'aria-haspopup': true, 'data-toggle': 'dropdown', type: 'button') do
    end + (:div, capture(&block), class: 'dropdown-menu')
  end
end


56
57
58
59
60
# File 'app/helpers/effective_bootstrap_helper.rb', line 56

def dots_link_to(label, path, options = {})
  options[:class] = [options[:class], 'dropdown-item'].compact.join(' ')

  concat link_to(label, path, options)
end

Button Dropdowns https://getbootstrap.com/docs/4.0/components/dropdowns/

dropdown do

dropdown_link_to 'Something', root_path

dropdown_divider

dropdown_link_to 'Another', root_path

Button Dropdowns variations can be :dropup, :dropleft, :dropright split can be true, false right is to right align things



16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
# File 'app/helpers/effective_bootstrap_helper.rb', line 16

def dropdown(variation: nil, split: true, btn: 'btn-outline-primary', right: false, &block)
  raise 'expected a block' unless block_given?

  @_dropdown_link_tos = []; yield

  return @_dropdown_link_tos.first if @_dropdown_link_tos.length <= 1

  retval = if split
    first = @_dropdown_link_tos.first
    menu = (:div, @_dropdown_link_tos[1..-1].join.html_safe, class: ['dropdown-menu', ('dropdown-menu-right' if right)].compact.join(' '))
    split = (:button, class: "btn #{btn} dropdown-toggle dropdown-toggle-split", type: 'button', 'data-toggle': 'dropdown', 'aria-haspopup': true, 'aria-expanded': false) do
      (:span, 'Toggle Dropdown', class: 'sr-only')
    end

    (:div, class: 'btn-group') do
      (:div, class: ['btn-group', variation.to_s.presence].compact.join(' '), role: 'group') do
        [:dropleft].include?(variation) ? (split + menu + first) : (first + split + menu)
      end
    end
  else
    raise 'split false is unsupported'
  end

  @_dropdown_link_tos = nil

  retval
end

Works with dots ao and dropdown do



81
82
83
84
85
86
87
88
# File 'app/helpers/effective_bootstrap_helper.rb', line 81

def dropdown_divider
  unless @_dropdown_link_tos
    (:div, '', class: 'dropdown-divider')
  else
    @_dropdown_link_tos << (:div, '', class: 'dropdown-divider')
    nil
  end
end

Works with dots do and dropdown do



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'app/helpers/effective_bootstrap_helper.rb', line 63

def dropdown_link_to(label, path, options = {})
  unless @_dropdown_link_tos
    options[:class] = [options[:class], 'dropdown-item'].compact.join(' ')
    return link_to(label, path, options)
  end

  if @_dropdown_link_tos.length == 0
    options[:class] = [options[:class], 'btn btn-outline-primary'].compact.join(' ') unless options[:class].to_s.include?('btn-')
  else
    options[:class] = [options[:class], 'dropdown-item'].compact.join(' ')
  end

  @_dropdown_link_tos << link_to(label, path, options)

  nil
end

#list_group(&block) ⇒ Object



90
91
92
# File 'app/helpers/effective_bootstrap_helper.rb', line 90

def list_group(&block)
  (:div, yield, class: 'list-group')
end

List group

list_group_link_to

Automatically puts in the 'active' class based on request path



97
98
99
100
101
102
103
104
105
106
# File 'app/helpers/effective_bootstrap_helper.rb', line 97

def list_group_link_to(label, path, opts = {})
  # Regular link item
  opts[:class] = if request.fullpath.include?(path)
    [opts[:class], 'list-group-item active'].compact.join(' ')
  else
    [opts[:class], 'list-group-item'].compact.join(' ')
  end

  link_to(label.to_s, path, opts)
end

#merge_class_key(hash, value) ⇒ Object



146
147
148
149
150
151
152
153
154
# File 'app/helpers/effective_bootstrap_helper.rb', line 146

def merge_class_key(hash, value)
  return { :class => value } unless hash.kind_of?(Hash)

  if hash[:class].present?
    hash.merge!(:class => "#{hash[:class]} #{value}")
  else
    hash.merge!(:class => value)
  end
end


142
143
144
# File 'app/helpers/effective_bootstrap_helper.rb', line 142

def nav_divider
  (:div, '', class: 'dropdown-divider')
end


128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'app/helpers/effective_bootstrap_helper.rb', line 128

def nav_dropdown(label, right: false, link_class: [], list_class: [], &block)
  raise 'expected a block' unless block_given?

  id = "dropdown-#{''.object_id}"

  (:li, class: 'nav-item dropdown') do
    (:a, class: 'nav-link dropdown-toggle', href: '#', id: id, role: 'button', 'data-toggle': 'dropdown', 'aria-haspopup': true, 'aria-expanded': false) do
      label.html_safe
    end + (:div, class: (right ? 'dropdown-menu dropdown-menu-right' : 'dropdown-menu'), 'aria-labelledby': id) do
      @_nav_mode = :dropdown; yield; @_nav_mode = nil
    end
  end
end

%ul.navbar-nav

nav_link_to 'Sign In', new_user_session_path

nav_dropdown 'Settings' do

= nav_link_to 'Account Settings', 
= nav_dropdown_divider
= nav_link_to 'Sign In', new_user_session_path, method: :delete


117
118
119
120
121
122
123
124
125
126
# File 'app/helpers/effective_bootstrap_helper.rb', line 117

def nav_link_to(label, path, opts = {})
  if @_nav_mode == :dropdown  # We insert dropdown-items
    return link_to(label, path, merge_class_key(opts, 'dropdown-item'))
  end

  # Regular nav link item
  (:li, class: (request.fullpath.include?(path) ? 'nav-item active' : 'nav-item')) do
    link_to(label, path, merge_class_key(opts, 'nav-link'))
  end
end